dnstrace

package module
v0.0.0-...-b888a31 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 31, 2023 License: MIT Imports: 3 Imported by: 0

README

dnstrace

This tool performs a DNS resolution by tracing the delegation path from the root name servers, and by following the CNAME chain. Each query is reported with statistics about all delegated name servers.

Features

  • Follow CNAMEs
  • Query all name servers in parallel and report stats for each
  • Report about non glued name server lookup time
  • Enable DNSSEC query option to better emulate name server queries
  • Compute the cold best path as if the resolver started with an empty cache to recurse queried name

Usage

Usage: dnstrace [qtype] <domain>

  -color
    	Enable/disable colors (default true)

Install

Using homebrew:

brew install rs/tap/dnstrace

From source:

go install github.com/ateliersjp/dnstrace@latest

Or download a binary package.

License

All source code is licensed under the MIT License.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Query

func Query(qname, qtype string) map[string][]Nameserver

Types

type Nameserver

type Nameserver struct {
	Name string
	TTL  uint32
}

Directories

Path Synopsis

Jump to